==> 0.0.1.tar.gz: example/lib/pages/swipe_cell.dart <==
import 'package:flutter/material.dart';
import 'package:millui/millui.dart';

class SwipeCell extends StatefulWidget {
  _SwipeCell createState() => _SwipeCell();
}

class _SwipeCell extends State<SwipeCell> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('SwiperCell'),
      ),
      body: Column(
        children: [
          MillSwipeCell(
            child: Container(
              height: 60,
              alignment: Alignment.centerLeft,
              decoration: BoxDecoration(
                border: Border(
                  bottom: BorderSide(
                    width: 2,
                    color: Color(0xfff1f1f1),
                  ),
                ),
              ),
              child: Text('智能营销平台'),
            ),
            suffixs: [
              GestureDetector(
                onTap: () {
                  print(123);
                },
                child: Container(
                  alignment: Alignment.center,
                  width: 100,
                  height: 60,
                  color: Colors.green,
                  child: Text('closer'),
                ),
              ),
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 60,
                color: Colors.red,
                child: Text('delete'),
              )
            ],
          ),
          MillSwipeCell(
            child: Container(
              height: 60,
              alignment: Alignment.centerLeft,
              decoration: BoxDecoration(
                border: Border(
                  bottom: BorderSide(
                    width: 2,
                    color: Color(0xfff1f1f1),
                  ),
                ),
              ),
              child: Text('双十一，买！买！买！'),
            ),
            prefixs: [
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 60,
                color: Colors.green,
                child: Text('closer'),
              ),
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 60,
                color: Colors.red,
                child: Text('delete'),
              )
            ],
            suffixs: [
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 60,
                color: Colors.green,
                child: Text('closer'),
              ),
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 60,
                color: Colors.red,
                child: Text('delete'),
              )
            ],
          ),
          MillSwipeCell(
            child: Container(
              height: 60,
              alignment: Alignment.centerLeft,
              decoration: BoxDecoration(
                border: Border(
                  bottom: BorderSide(
                    width: 2,
                    color: Color(0xfff1f1f1),
                  ),
                ),
              ),
              child: Text('今年不想剁手了！'),
            ),
            prefixs: [
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 60,
                color: Colors.green,
                child: Text('closer'),
              ),
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 60,
                color: Colors.red,
                child: Text('delete'),
              )
            ],
          ),
        ],
      ),
    );
  }
}

==> 0.0.4.tar.gz: example/lib/pages/swipe_cell.dart <==
import 'package:flutter/material.dart';
import 'package:millui/millui.dart';

import '../app_provider.dart';

class SwipeCell extends StatefulWidget {
  _SwipeCell createState() => _SwipeCell();
}

class _SwipeCell extends State<SwipeCell> {
  @override
  Widget build(BuildContext context) {
    bool isCn = getLanage(context);

    return Scaffold(
      appBar: AppBar(
        title: Text('SwiperCell'),
      ),
      body: Column(
        children: [
          MillSwipeCell(
            child: Container(
              height: 60,
              alignment: Alignment.centerLeft,
              padding: EdgeInsets.only(left: 10),
              decoration: BoxDecoration(
                border: Border(
                  bottom: BorderSide(
                    width: 2,
                    color: Color(0xfff1f1f1),
                  ),
                ),
              ),
              child: Text(isCn ? '白日依山尽' : ' No one and you'),
            ),
            suffixs: [
              GestureDetector(
                onTap: () {
                  print(123);
                },
                child: Container(
                  alignment: Alignment.center,
                  width: 100,
                  height: 60,
                  color: Colors.green,
                  child: Text('closer', style: TextStyle(color: Colors.white)),
                ),
              ),
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 60,
                color: Colors.red,
                child: Text('delete', style: TextStyle(color: Colors.white)),
              )
            ],
          ),
          MillSwipeCell(
            child: Container(
              height: 120,
              alignment: Alignment.centerLeft,
              padding: EdgeInsets.only(left: 10),
              decoration: BoxDecoration(
                border: Border(
                  bottom: BorderSide(
                    width: 2,
                    color: Color(0xfff1f1f1),
                  ),
                ),
              ),
              child: Text(isCn ? '黄河入海流' : 'Bad days will pass'),
            ),
            prefixs: [
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 120,
                color: Colors.green,
                child: Text('closer', style: TextStyle(color: Colors.white)),
              ),
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 120,
                color: Colors.red,
                child: Text('delete', style: TextStyle(color: Colors.white)),
              )
            ],
            suffixs: [
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 120,
                color: Colors.green,
                child: Text('closer', style: TextStyle(color: Colors.white)),
              ),
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 120,
                color: Colors.red,
                child: Text('delete', style: TextStyle(color: Colors.white)),
              )
            ],
          ),
          MillSwipeCell(
            child: Container(
              height: 60,
              alignment: Alignment.centerLeft,
              padding: EdgeInsets.only(left: 10),
              decoration: BoxDecoration(
                border: Border(
                  bottom: BorderSide(
                    width: 2,
                    color: Color(0xfff1f1f1),
                  ),
                ),
              ),
              child: Text(isCn ? '今年不想剁手了！' : 'love you just because.'),
            ),
            prefixs: [
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 60,
                color: Colors.green,
                child: Text('closer', style: TextStyle(color: Colors.white)),
              ),
              Container(
                alignment: Alignment.center,
                width: 100,
                height: 60,
                color: Colors.red,
                child: Text('delete', style: TextStyle(color: Colors.white)),
              )
            ],
          ),
        ],
      ),
    );
  }
}
